@@ -17,7 +17,9 @@
 package org.uberfire.ext.editor.commons.client;
 
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.HashSet;
+import java.util.Map;
 import java.util.function.Supplier;
 
 import com.google.gwt.user.client.ui.IsWidget;
@@ -34,6 +36,7 @@ import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
 import org.uberfire.client.workbench.type.ClientResourceType;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
+import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItem;
 import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.ext.editor.commons.client.validation.Validator;
 import org.uberfire.ext.editor.commons.file.DefaultMetadata;
@@ -43,6 +46,7 @@ import org.uberfire.mvp.Command;
 import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.model.menu.MenuItem;
+import org.uberfire.workbench.model.menu.Menus;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -59,6 +63,7 @@ import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 import static org.uberfire.ext.editor.commons.client.menu.MenuItems.COPY;
 import static org.uberfire.ext.editor.commons.client.menu.MenuItems.DELETE;
+import static org.uberfire.ext.editor.commons.client.menu.MenuItems.DOWNLOAD;
 import static org.uberfire.ext.editor.commons.client.menu.MenuItems.HISTORY;
 import static org.uberfire.ext.editor.commons.client.menu.MenuItems.RENAME;
 import static org.uberfire.ext.editor.commons.client.menu.MenuItems.SAVE;
@@ -81,6 +86,9 @@ public class BaseEditorTest {
     @Mock
     private EventSourceMock<ChangeTitleWidgetEvent> changeTitleNotification;
 
+    @Mock
+    private DownloadMenuItem downloadMenuItem;
+
     private SaveAndRenameCommandBuilder<String, DefaultMetadata> builder = spy(makeBuilder());
 
     @InjectMocks
@@ -343,8 +351,11 @@ public class BaseEditorTest {
         final Validator copyValidator = mock(Validator.class);
         final Caller copyServiceCaller = mock(Caller.class);
         final Caller deleteServiceCaller = mock(Caller.class);
+        final MenuItem downloadMenuItemButton = mock(MenuItem.class);
 
-        editor.menuItems = new HashSet<>(Arrays.asList(SAVE, COPY, RENAME, DELETE, VALIDATE, HISTORY));
+        when(downloadMenuItem.build(any())).thenReturn(downloadMenuItemButton);
+
+        editor.menuItems = new HashSet<>(Arrays.asList(SAVE, COPY, RENAME, DELETE, VALIDATE, HISTORY, DOWNLOAD));
 
         doReturn(path).when(versionRecordManager).getCurrentPath();
         doReturn(menuItem).when(versionRecordManager).buildMenu();
@@ -364,6 +375,7 @@ public class BaseEditorTest {
         verify(menuBuilder).addDelete(path, deleteServiceCaller);
         verify(menuBuilder).addValidate(onValidate);
         verify(menuBuilder).addNewTopLevelMenu(menuItem);
+        verify(menuBuilder).addNewTopLevelMenu(downloadMenuItemButton);
     }
 
     @Test
@@ -531,6 +543,38 @@ public class BaseEditorTest {
         assertEquals(expectedHash, actualHash);
     }
 
+    @Test
+    public void testDisableMenuItem() {
+
+        final Menus menus = mock(Menus.class);
+        final MenuItem menuItem = mock(MenuItem.class);
+        final Map<Object, MenuItem> itemMap = new HashMap<>();
+
+        itemMap.put(SAVE, menuItem);
+        when(menus.getItemsMap()).thenReturn(itemMap);
+        doReturn(menus).when(editor).menus();
+
+        editor.disableMenuItem(SAVE);
+
+        verify(menuItem).setEnabled(false);
+    }
+
+    @Test
+    public void testEnableMenuItem() {
+
+        final Menus menus = mock(Menus.class);
+        final MenuItem menuItem = mock(MenuItem.class);
+        final Map<Object, MenuItem> itemMap = new HashMap<>();
+
+        itemMap.put(SAVE, menuItem);
+        when(menus.getItemsMap()).thenReturn(itemMap);
+        doReturn(menus).when(editor).menus();
+
+        editor.enableMenuItem(SAVE);
+
+        verify(menuItem).setEnabled(true);
+    }
+
     private DefaultMetadata fakeMetadata(final int hashCode) {
         return new DefaultMetadata() {
             @Override
