@@ -26,8 +26,11 @@ import com.ait.lienzo.client.core.shape.MultiPath;
 import com.ait.lienzo.client.core.shape.Text;
 import com.ait.lienzo.client.core.types.BoundingBox;
 import com.google.gwt.core.client.GWT;
+import org.uberfire.ext.wires.core.grids.client.model.GridCell;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
+import org.uberfire.ext.wires.core.grids.client.util.ColumnIndexUtilities;
+import org.uberfire.ext.wires.core.grids.client.widget.context.GridBodyCellRenderContext;
 import org.uberfire.ext.wires.core.grids.client.widget.context.GridBodyColumnRenderContext;
 import org.uberfire.ext.wires.core.grids.client.widget.context.GridHeaderColumnRenderContext;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.columns.GridColumnRenderer;
@@ -69,14 +72,14 @@ public abstract class BaseGridColumnRenderer<T> implements GridColumnRenderer<T>
 
                 for (int headerRowIndex = 0; headerRowIndex < headerMetaData.size(); headerRowIndex++) {
                     //Get extents of block for Header cell
-                    final int blockStartColumnIndex = getBlockStartColumnIndex(allBlockColumns,
-                                                                               headerMetaData.get(headerRowIndex),
-                                                                               headerRowIndex,
-                                                                               headerColumnIndex);
-                    final int blockEndColumnIndex = getBlockEndColumnIndex(allBlockColumns,
-                                                                           headerMetaData.get(headerRowIndex),
-                                                                           headerRowIndex,
-                                                                           headerColumnIndex);
+                    final int blockStartColumnIndex = ColumnIndexUtilities.getHeaderBlockStartColumnIndex(allBlockColumns,
+                                                                                                          headerMetaData.get(headerRowIndex),
+                                                                                                          headerRowIndex,
+                                                                                                          headerColumnIndex);
+                    final int blockEndColumnIndex = ColumnIndexUtilities.getHeaderBlockEndColumnIndex(allBlockColumns,
+                                                                                                      headerMetaData.get(headerRowIndex),
+                                                                                                      headerRowIndex,
+                                                                                                      headerColumnIndex);
 
                     //Vertical grid lines
                     if (headerColumnIndex < model.getColumnCount() - 1) {
@@ -125,14 +128,14 @@ public abstract class BaseGridColumnRenderer<T> implements GridColumnRenderer<T>
                 final Group g = new Group().setX(x);
                 for (int headerRowIndex = 0; headerRowIndex < headerMetaData.size(); headerRowIndex++) {
                     //Get extents of block for Header cell
-                    final int blockStartColumnIndex = getBlockStartColumnIndex(allBlockColumns,
-                                                                               headerMetaData.get(headerRowIndex),
-                                                                               headerRowIndex,
-                                                                               headerColumnIndex);
-                    final int blockEndColumnIndex = getBlockEndColumnIndex(allBlockColumns,
-                                                                           headerMetaData.get(headerRowIndex),
-                                                                           headerRowIndex,
-                                                                           headerColumnIndex);
+                    final int blockStartColumnIndex = ColumnIndexUtilities.getHeaderBlockStartColumnIndex(allBlockColumns,
+                                                                                                          headerMetaData.get(headerRowIndex),
+                                                                                                          headerRowIndex,
+                                                                                                          headerColumnIndex);
+                    final int blockEndColumnIndex = ColumnIndexUtilities.getHeaderBlockEndColumnIndex(allBlockColumns,
+                                                                                                      headerMetaData.get(headerRowIndex),
+                                                                                                      headerRowIndex,
+                                                                                                      headerColumnIndex);
 
                     //Check whether we need to render clipped cell (we only render once for blocks spanning multiple columns)
                     boolean skip;
@@ -153,8 +156,8 @@ public abstract class BaseGridColumnRenderer<T> implements GridColumnRenderer<T>
                                                             blockStartColumnIndex,
                                                             blockEndColumnIndex);
 
-                    final Group headerGroup = renderHeaderContent(context,
-                                                                  headerMetaData,
+                    final Group headerGroup = renderHeaderContent(headerMetaData,
+                                                                  context,
                                                                   headerRowIndex,
                                                                   blockWidth,
                                                                   rowHeight);
@@ -183,11 +186,12 @@ public abstract class BaseGridColumnRenderer<T> implements GridColumnRenderer<T>
         return new BoundingBoxPathClipper(bb);
     }
 
-    protected Group renderHeaderContent(final GridHeaderColumnRenderContext context,
-                                        final List<GridColumn.HeaderMetaData> headerMetaData,
-                                        final int headerRowIndex,
-                                        final double blockWidth,
-                                        final double rowHeight) {
+    @Override
+    public Group renderHeaderContent(final List<GridColumn.HeaderMetaData> headerMetaData,
+                                     final GridHeaderColumnRenderContext context,
+                                     final int headerRowIndex,
+                                     final double blockWidth,
+                                     final double rowHeight) {
         final Group headerGroup = GWT.create(Group.class);
         final String title = headerMetaData.get(headerRowIndex).getTitle();
         final Text t = context.getRenderer().getTheme().getHeaderText();
@@ -199,56 +203,6 @@ public abstract class BaseGridColumnRenderer<T> implements GridColumnRenderer<T>
         return headerGroup;
     }
 
-    @SuppressWarnings("unchecked")
-    private int getBlockStartColumnIndex(final List<GridColumn<?>> allColumns,
-                                         final GridColumn.HeaderMetaData headerMetaData,
-                                         final int headerRowIndex,
-                                         final int headerColumnIndex) {
-        //Back-track adding width of proceeding columns sharing header MetaData
-        int candidateHeaderColumnIndex = headerColumnIndex;
-        if (candidateHeaderColumnIndex == 0) {
-            return candidateHeaderColumnIndex;
-        }
-        while (candidateHeaderColumnIndex > 0) {
-            final GridColumn candidateColumn = allColumns.get(candidateHeaderColumnIndex - 1);
-            final List<GridColumn.HeaderMetaData> candidateHeaderMetaData = candidateColumn.getHeaderMetaData();
-            if (candidateHeaderMetaData.size() - 1 < headerRowIndex) {
-                break;
-            }
-            if (!candidateHeaderMetaData.get(headerRowIndex).equals(headerMetaData)) {
-                break;
-            }
-            candidateHeaderColumnIndex--;
-        }
-
-        return candidateHeaderColumnIndex;
-    }
-
-    @SuppressWarnings("unchecked")
-    private int getBlockEndColumnIndex(final List<GridColumn<?>> allColumns,
-                                       final GridColumn.HeaderMetaData headerMetaData,
-                                       final int headerRowIndex,
-                                       final int headerColumnIndex) {
-        //Forward-track adding width of following columns sharing header MetaData
-        int candidateHeaderColumnIndex = headerColumnIndex;
-        if (candidateHeaderColumnIndex == allColumns.size() - 1) {
-            return candidateHeaderColumnIndex;
-        }
-        while (candidateHeaderColumnIndex < allColumns.size() - 1) {
-            final GridColumn candidateColumn = allColumns.get(candidateHeaderColumnIndex + 1);
-            final List<GridColumn.HeaderMetaData> candidateHeaderMetaData = candidateColumn.getHeaderMetaData();
-            if (candidateHeaderMetaData.size() - 1 < headerRowIndex) {
-                break;
-            }
-            if (!candidateHeaderMetaData.get(headerRowIndex).equals(headerMetaData)) {
-                break;
-            }
-            candidateHeaderColumnIndex++;
-        }
-
-        return candidateHeaderColumnIndex;
-    }
-
     private double getBlockOffset(final List<GridColumn<?>> allColumns,
                                   final int blockStartColumnIndex,
                                   final int headerColumnIndex) {
@@ -295,4 +249,39 @@ public abstract class BaseGridColumnRenderer<T> implements GridColumnRenderer<T>
                                                            columnRenderingConstraint);
         }
     }
+
+    /**
+     * Return the <code>Group</code> holding the <b>cell</b> data
+     * @param cell
+     * @param context
+     * @param text code the <code>Text</code> that will contain the data to show
+     * @param value the String to show
+     * @return
+     */
+    protected Group internalRenderCell(final GridCell<T> cell,
+                                       final GridBodyCellRenderContext context,
+                                       final Text text,
+                                       final String value) {
+        if (value == null) {
+            return null;
+        }
+
+        final Group g = new Group();
+
+        text.setText(value);
+        text.setListening(false);
+        text.setX(context.getCellWidth() / 2);
+        text.setY(context.getCellHeight() / 2);
+
+        g.add(text);
+        return g;
+    }
+
+    protected boolean isToReturnNull(final GridCell<T> cell) {
+        return cell == null || cell.getValue() == null || (cell.getValue().getValue() == null && cell.getValue().getPlaceHolder() == null);
+    }
+
+    protected boolean isPlaceHolderToBeShown(final GridCell<T> cell) {
+        return cell.getValue() != null && cell.getValue().getValue() == null && cell.getValue().getPlaceHolder() != null;
+    }
 }
